pub fn assert_native_coin(asset: &Asset) -> StdResult<Coin>Expand description
Assert that an asset is a native token.
Returns
Returns an error if the asset is not a native token.
Returns a StdResult<Coin> containing the asset as a coin if it is a native
token.