assert_native_token_received

Function assert_native_token_received 

pub fn assert_native_token_received(
    info: &MessageInfo,
    asset: &Asset,
) -> StdResult<()>
Assert that a specific native token in the form of an Asset was sent to the contract.