assert_only_native_coins

Function assert_only_native_coins 

pub fn assert_only_native_coins(assets: &AssetList) -> StdResult<Vec<Coin>>
Assert that all assets in the AssetList are native tokens.

Returns

Returns an error if any of the assets are not native tokens. Returns a StdResult<Vec<Coin>> containing the assets as coins if they are all native tokens.